@@ -19,7 +19,7 @@
 #'   be consistent; if consistency is needed, you must provide a non-\code{NULL}
 #'   domain.
 #' @param na.color The color to return for \code{NA} values. Note that
-#'   \code{na.color=NA} is valid.
+#'   \code{na.color = NA} is valid.
 #' @param alpha Whether alpha channels should be respected or ignored. If
 #'   \code{TRUE} then colors without explicit alpha information will be treated
 #'   as fully opaque.
@@ -31,28 +31,28 @@
 #' @return A function that takes a single parameter \code{x}; when called with a
 #'   vector of numbers (except for \code{colorFactor}, which expects
 #'   factors/characters), #RRGGBB color strings are returned (unless
-#'   \code{alpha=TRUE} in which case #RRGGBBAA may also be possible).
+#'   \code{alpha = TRUE} in which case #RRGGBBAA may also be possible).
 #'
 #' @export
 colorNumeric <- function(palette, domain, na.color = "#808080", alpha = FALSE, reverse = FALSE) {
-  rng = NULL
+  rng <- NULL
   if (length(domain) > 0) {
-    rng = range(domain, na.rm = TRUE)
+    rng <- range(domain, na.rm = TRUE)
     if (!all(is.finite(rng))) {
       stop("Wasn't able to determine range of domain")
     }
   }
 
-  pf = safePaletteFunc(palette, na.color, alpha)
+  pf <- safePaletteFunc(palette, na.color, alpha)
 
-  withColorAttr('numeric', list(na.color = na.color), function(x) {
+  withColorAttr("numeric", list(na.color = na.color), function(x) {
     if (length(x) == 0 || all(is.na(x))) {
       return(pf(x))
     }
 
-    if (is.null(rng)) rng = range(x, na.rm = TRUE)
+    if (is.null(rng)) rng <- range(x, na.rm = TRUE)
 
-    rescaled = scales::rescale(x, from = rng)
+    rescaled <- scales::rescale(x, from = rng)
     if (any(rescaled < 0 | rescaled > 1, na.rm = TRUE))
       warning("Some values were outside the color scale and will be treated as NA")
 
@@ -88,13 +88,15 @@ getBins <- function(domain, x, bins, pretty) {
   if (pretty) {
     base::pretty(domain %||% x, n = bins)
   } else {
-    rng = range(domain %||% x, na.rm = TRUE)
+    rng <- range(domain %||% x, na.rm = TRUE)
     seq(rng[1], rng[2], length.out = bins + 1)
   }
 }
 
 #' @details \code{colorBin} also maps continuous numeric data, but performs
-#'   binning based on value (see the \code{\link[base]{cut}} function).
+#'   binning based on value (see the \code{\link[base]{cut}} function). \code{colorBin}
+#'   defaults for the \code{\link[base]{cut}} function are \code{include.lowest
+#'   = TRUE} and \code{right = FALSE}.
 #' @param bins Either a numeric vector of two or more unique cut points or a
 #'   single number (greater than or equal to 2) giving the number of intervals
 #'   into which the domain values are to be cut.
@@ -103,30 +105,31 @@ getBins <- function(domain, x, bins, pretty) {
 #'   \code{pretty = TRUE}, the actual number of bins may not be the number of
 #'   bins you specified. When \code{pretty = FALSE}, \code{\link{seq}()} is used
 #'   to generate the bins and the breaks may not be "pretty".
+#' @param right parameter supplied to cut. See Details
 #' @rdname colorNumeric
 #' @export
 colorBin <- function(palette, domain, bins = 7, pretty = TRUE,
-  na.color = "#808080", alpha = FALSE, reverse = FALSE) {
+  na.color = "#808080", alpha = FALSE, reverse = FALSE, right = FALSE) {
 
   # domain usually needs to be explicitly provided (even if NULL) but not if
   # breaks are specified
   if (missing(domain) && length(bins) > 1) {
-    domain = NULL
+    domain <- NULL
   }
-  autobin = is.null(domain) && length(bins) == 1
+  autobin <- is.null(domain) && length(bins) == 1
   if (!is.null(domain))
-    bins = getBins(domain, NULL, bins, pretty)
-  numColors = if (length(bins) == 1) bins else length(bins) - 1
-  colorFunc = colorFactor(palette, domain = if (!autobin) 1:numColors,
+    bins <- getBins(domain, NULL, bins, pretty)
+  numColors <- if (length(bins) == 1) bins else length(bins) - 1
+  colorFunc <- colorFactor(palette, domain = if (!autobin) 1:numColors,
     na.color = na.color, alpha = alpha, reverse = reverse)
-  pf = safePaletteFunc(palette, na.color, alpha)
+  pf <- safePaletteFunc(palette, na.color, alpha)
 
-  withColorAttr('bin', list(bins = bins, na.color = na.color), function(x) {
+  withColorAttr("bin", list(bins = bins, na.color = na.color), function(x) {
     if (length(x) == 0 || all(is.na(x))) {
       return(pf(x))
     }
-    binsToUse = getBins(domain, x, bins, pretty)
-    ints = cut(x, binsToUse, labels = FALSE, include.lowest = TRUE, right = FALSE)
+    binsToUse <- getBins(domain, x, bins, pretty)
+    ints <- cut(x, binsToUse, labels = FALSE, include.lowest = TRUE, right = right)
     if (any(is.na(x) != is.na(ints)))
       warning("Some values were outside the color scale and will be treated as NA")
     colorFunc(ints)
@@ -143,12 +146,12 @@ colorBin <- function(palette, domain, bins = 7, pretty = TRUE,
 #' @export
 colorQuantile <- function(palette, domain, n = 4,
   probs = seq(0, 1, length.out = n + 1), na.color = "#808080", alpha = FALSE,
-  reverse = FALSE) {
+  reverse = FALSE, right = FALSE) {
 
   if (!is.null(domain)) {
-    bins = quantile(domain, probs, na.rm = TRUE, names = FALSE)
+    bins <- quantile(domain, probs, na.rm = TRUE, names = FALSE)
     return(withColorAttr(
-      'quantile', list(probs = probs, na.color = na.color),
+      "quantile", list(probs = probs, na.color = na.color),
       colorBin(palette, domain = NULL, bins = bins, na.color = na.color,
         alpha = alpha, reverse = reverse)
     ))
@@ -157,12 +160,12 @@ colorQuantile <- function(palette, domain, n = 4,
   # I don't have a precise understanding of how quantiles are meant to map to colors.
   # If you say probs = seq(0, 1, 0.25), which has length 5, does that map to 4 colors
   # or 5? 4, right?
-  colorFunc = colorFactor(palette, domain = 1:(length(probs) - 1),
+  colorFunc <- colorFactor(palette, domain = 1:(length(probs) - 1),
     na.color = na.color, alpha = alpha, reverse = reverse)
 
-  withColorAttr('quantile', list(probs = probs, na.color = na.color), function(x) {
-    binsToUse = quantile(x, probs, na.rm = TRUE, names = FALSE)
-    ints = cut(x, binsToUse, labels = FALSE, include.lowest = TRUE, right = FALSE)
+  withColorAttr("quantile", list(probs = probs, na.color = na.color), function(x) {
+    binsToUse <- quantile(x, probs, na.rm = TRUE, names = FALSE)
+    ints <- cut(x, binsToUse, labels = FALSE, include.lowest = TRUE, right = right)
     if (any(is.na(x) != is.na(ints)))
       warning("Some values were outside the color scale and will be treated as NA")
     colorFunc(ints)
@@ -211,30 +214,31 @@ colorFactor <- function(palette, domain, levels = NULL, ordered = FALSE,
   # domain usually needs to be explicitly provided (even if NULL) but not if
   # levels are specified
   if (missing(domain) && !is.null(levels)) {
-    domain = NULL
+    domain <- NULL
   }
 
   if (!is.null(levels) && anyDuplicated(levels)) {
     warning("Duplicate levels detected")
-    levels = unique(levels)
+    levels <- unique(levels)
   }
-  lvls = getLevels(domain, NULL, levels, ordered)
+  lvls <- getLevels(domain, NULL, levels, ordered)
 
-  withColorAttr('factor', list(na.color = na.color), function(x) {
+  force(palette) # palette loses scope
+  withColorAttr("factor", list(na.color = na.color), function(x) {
     if (length(x) == 0 || all(is.na(x))) {
       return(rep.int(na.color, length(x)))
     }
 
-    lvls = getLevels(domain, x, lvls, ordered)
-    pf = safePaletteFunc(palette, na.color, alpha, nlevels = length(lvls) * ifelse(reverse, -1, 1))
+    lvls <- getLevels(domain, x, lvls, ordered)
+    pf <- safePaletteFunc(palette, na.color, alpha, nlevels = length(lvls) * ifelse(reverse, -1, 1))
 
-    origNa = is.na(x)
-    x = match(as.character(x), lvls)
+    origNa <- is.na(x)
+    x <- match(as.character(x), lvls)
     if (any(is.na(x) != origNa)) {
       warning("Some values were outside the color scale and will be treated as NA")
     }
 
-    scaled = scales::rescale(as.integer(x), from = c(1, length(lvls)))
+    scaled <- scales::rescale(as.integer(x), from = c(1, length(lvls)))
     if (any(scaled < 0 | scaled > 1, na.rm = TRUE)) {
       warning("Some values were outside the color scale and will be treated as NA")
     }
@@ -250,26 +254,26 @@ colorFactor <- function(palette, domain, levels = NULL, ordered = FALSE,
 #'   \item{A character vector of RGB or named colors. Examples: \code{palette()}, \code{c("#000000", "#0000FF", "#FFFFFF")}, \code{topo.colors(10)}}
 #'   \item{The name of an RColorBrewer palette, e.g. \code{"BuPu"} or \code{"Greens"}.}
 #'   \item{The full name of a viridis palette: \code{"viridis"}, \code{"magma"}, \code{"inferno"}, or \code{"plasma"}.}
-#'   \item{A function that receives a single value between 0 and 1 and returns a color. Examples: \code{colorRamp(c("#000000", "#FFFFFF"), interpolate="spline")}.}
+#'   \item{A function that receives a single value between 0 and 1 and returns a color. Examples: \code{colorRamp(c("#000000", "#FFFFFF"), interpolate = "spline")}.}
 #' }
 #' @examples
-#' pal = colorBin("Greens", domain = 0:100)
+#' pal <- colorBin("Greens", domain = 0:100)
 #' pal(runif(10, 60, 100))
 #'
 #' \donttest{
-#' # Exponential distribution, mapped continuously
-#' previewColors(colorNumeric("Blues", domain = NULL), sort(rexp(16)))
-#' # Exponential distribution, mapped by interval
-#' previewColors(colorBin("Blues", domain = NULL, bins = 4), sort(rexp(16)))
-#' # Exponential distribution, mapped by quantile
-#' previewColors(colorQuantile("Blues", domain = NULL), sort(rexp(16)))
+#'  # Exponential distribution, mapped continuously
+#'  previewColors(colorNumeric("Blues", domain = NULL), sort(rexp(16)))
+#'  # Exponential distribution, mapped by interval
+#'  previewColors(colorBin("Blues", domain = NULL, bins = 4), sort(rexp(16)))
+#'  # Exponential distribution, mapped by quantile
+#'  previewColors(colorQuantile("Blues", domain = NULL), sort(rexp(16)))
 #'
-#' # Categorical data; by default, the values being colored span the gamut...
-#' previewColors(colorFactor("RdYlBu", domain = NULL), LETTERS[1:5])
-#' # ...unless the data is a factor, without droplevels...
-#' previewColors(colorFactor("RdYlBu", domain = NULL), factor(LETTERS[1:5], levels=LETTERS))
-#' # ...or the domain is stated explicitly.
-#' previewColors(colorFactor("RdYlBu", levels = LETTERS), LETTERS[1:5])
+#'  # Categorical data; by default, the values being colored span the gamut...
+#'  previewColors(colorFactor("RdYlBu", domain = NULL), LETTERS[1:5])
+#'  # ...unless the data is a factor, without droplevels...
+#'  previewColors(colorFactor("RdYlBu", domain = NULL), factor(LETTERS[1:5], levels = LETTERS))
+#'  # ...or the domain is stated explicitly.
+#'  previewColors(colorFactor("RdYlBu", levels = LETTERS), LETTERS[1:5])
 #' }
 #' @rdname colorNumeric
 #' @name colorNumeric
@@ -277,7 +281,7 @@ NULL
 
 
 safePaletteFunc <- function(pal, na.color, alpha, nlevels = NULL) {
-  toPaletteFunc(pal, alpha=alpha, nlevels = nlevels) %>%
+  toPaletteFunc(pal, alpha = alpha, nlevels = nlevels) %>%
     filterRGB() %>%
     filterZeroLength() %>%
     filterNA(na.color) %>%
@@ -311,7 +315,7 @@ brewer_pal <- function(palette, n = NULL) {
   if (n == 1) {
     colors[1]
   } else if (n == 2) {
-    colors[c(1,3)]
+    colors[c(1, 3)]
   } else {
     colors
   }
@@ -321,7 +325,7 @@ brewer_pal <- function(palette, n = NULL) {
 # of an RColorBrewer palette that is marked as qualitative
 toPaletteFunc.character <- function(pal, alpha, nlevels) {
   if (length(pal) == 1 && pal %in% row.names(RColorBrewer::brewer.pal.info)) {
-    paletteInfo <- RColorBrewer::brewer.pal.info[pal,]
+    paletteInfo <- RColorBrewer::brewer.pal.info[pal, ]
     if (!is.null(nlevels)) {
       colors <- brewer_pal(pal, abs(nlevels))
     } else {
@@ -353,8 +357,8 @@ toPaletteFunc.function <- function(pal, alpha, nlevels) {
 #' @return An HTML-based list of the colors and values
 #' @export
 previewColors <- function(pal, values) {
-  heading = htmltools::tags$code(deparse(substitute(pal)))
-  subheading = htmltools::tags$code(deparse(substitute(values)))
+  heading <- htmltools::tags$code(deparse(substitute(pal)))
+  subheading <- htmltools::tags$code(deparse(substitute(values)))
 
   htmltools::browsable(
     with(htmltools::tags, htmltools::tagList(
@@ -380,7 +384,7 @@ previewColors <- function(pal, values) {
   )
 }
 
-# colorRamp(space = 'Lab') throws error when called with
+# colorRamp(space = "Lab") throws error when called with
 # zero-length input
 filterZeroLength <- function(f) {
   force(f)
@@ -397,10 +401,10 @@ filterZeroLength <- function(f) {
 filterNA <- function(f, na.color) {
   force(f)
   function(x) {
-    results = character(length(x))
-    nas = is.na(x)
-    results[nas] = na.color
-    results[!nas] = f(x[!nas])
+    results <- character(length(x))
+    nas <- is.na(x)
+    results[nas] <- na.color
+    results[!nas] <- f(x[!nas])
     results
   }
 }
@@ -409,7 +413,7 @@ filterNA <- function(f, na.color) {
 filterRGB <- function(f) {
   force(f)
   function(x) {
-    results = f(x)
+    results <- f(x)
     if (is.character(results)) {
       results
     } else if (is.matrix(results)) {
@@ -423,7 +427,7 @@ filterRGB <- function(f) {
 filterRange <- function(f) {
   force(f)
   function(x) {
-    x[x < 0 | x > 1] = NA
+    x[x < 0 | x > 1] <- NA
     f(x)
   }
 }
